@@ -12,15 +12,17 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package aws
+package aws // import "go.opentelemetry.io/contrib/propagators/aws"
 
 // Version is the current release version of the AWS XRay propagator.
 func Version() string {
-	return "1.0.0"
+	return "1.17.0"
 	// This string is updated by the pre_release.sh script during release
 }
 
 // SemVersion is the semantic version to be supplied to tracer/meter creation.
+//
+// Deprecated: Use [Version] instead.
 func SemVersion() string {
-	return "semver:" + Version()
+	return Version()
 }
